@@ -222,8 +222,8 @@ public class DefaultConnectorFactory implements ConnectorFactory {
     }
 
     @Override
-    public ValidateAccountConnector getValidateAccountConnector(SessionData sessionData, MailAccountData account, boolean forceInsecureConnection) {
-        return new ValidateAccountConnector(configuration, sessionData, account, forceInsecureConnection);
+    public ValidateAccountConnector getValidateAccountConnector(SessionData sessionData, MailAccountData account, boolean forceInsecureConnection, boolean ignoreInvalidTransport) {
+        return new ValidateAccountConnector(configuration, sessionData, account, forceInsecureConnection, ignoreInvalidTransport);
     }
 
     @Override
